==> haskell-mono-traversable-1.0.20.0-9-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mono-traversable.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 mono-traversable
version:              1.0.20.0
visibility:           public
id:                   mono-traversable-1.0.20.0-65ylpzjN1zPCOhHZUcOmWZ
key:                  mono-traversable-1.0.20.0-65ylpzjN1zPCOhHZUcOmWZ
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman, John Wiegley, Greg Weber
homepage:             https://github.com/snoyberg/mono-traversable#readme
synopsis:
    Type classes for mapping, folding, and traversing monomorphic containers

description:
    Please see the README at <https://www.stackage.org/package/mono-traversable>

category:             Data
abi:                  79714adaba02b3d0e3a793a2c2539eba
exposed:              True
exposed-modules:
    Data.Containers Data.MonoTraversable
    Data.MonoTraversable.Unprefixed Data.NonNull Data.Sequences

hidden-modules:       Paths_mono_traversable
import-dirs:          /usr/lib/ghc-9.2.8/site-local/mono-traversable-1.0.20.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/mono-traversable-1.0.20.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mono-traversable
hs-libraries:         HSmono-traversable-1.0.20.0-65ylpzjN1zPCOhHZUcOmWZ
depends:
    base-4.16.4.0 bytestring-0.11.4.0 containers-0.6.5.1
    hashable-1.4.4.0-DtL5AH6y1if92iaAq0qoKj
    split-0.2.5-D8Q5hs7UAOeFSfUt4jgpO4 text-1.2.5.0
    transformers-0.5.6.2
    unordered-containers-0.2.20-KbuohGKDXjMH23185MHhrF
    vector-0.13.1.0-1Hbj4hORR7KGMeSpv0BhQN
    vector-algorithms-0.9.0.2-AifrHUwW4R1Lt5bHdhxMQV

haddock-interfaces:
    /usr/share/doc/haskell-mono-traversable/html/mono-traversable.haddock

haddock-html:         /usr/share/doc/haskell-mono-traversable/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mono-traversable-1.0.20.0-11-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mono-traversable.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 mono-traversable
version:              1.0.20.0
visibility:           public
id:                   mono-traversable-1.0.20.0-BbUSWYcXr8M9RkrkturSr4
key:                  mono-traversable-1.0.20.0-BbUSWYcXr8M9RkrkturSr4
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman, John Wiegley, Greg Weber
homepage:             https://github.com/snoyberg/mono-traversable#readme
synopsis:
    Type classes for mapping, folding, and traversing monomorphic containers

description:
    Please see the README at <https://www.stackage.org/package/mono-traversable>

category:             Data
abi:                  85e72c714bbc2d24ee439d01f3d99f09
exposed:              True
exposed-modules:
    Data.Containers Data.MonoTraversable
    Data.MonoTraversable.Unprefixed Data.NonNull Data.Sequences

hidden-modules:       Paths_mono_traversable
import-dirs:          /usr/lib/ghc-9.2.8/site-local/mono-traversable-1.0.20.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/mono-traversable-1.0.20.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mono-traversable
hs-libraries:         HSmono-traversable-1.0.20.0-BbUSWYcXr8M9RkrkturSr4
depends:
    base-4.16.4.0 bytestring-0.11.4.0 containers-0.6.5.1
    hashable-1.4.4.0-BrYG523VafVKM4yDK0K7G3
    split-0.2.5-Gzu4NbNnTUj6rs5DfMztSh text-1.2.5.0
    transformers-0.5.6.2
    unordered-containers-0.2.20-HYi8F0R2X5DJGcgMLraHLn
    vector-0.13.1.0-Gf2urNiIAD32gZDiWE6SSZ
    vector-algorithms-0.9.0.3-45uzz5ue0WpB3836EsXUo2

haddock-interfaces:
    /usr/share/doc/haskell-mono-traversable/html/mono-traversable.haddock

haddock-html:         /usr/share/doc/haskell-mono-traversable/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
